from functools import wraps

from rook.interface import Rook

def serverless_rook(f):
    @wraps(f)
    def handler(*args, **kwargs):
        from rook import auto_start
        ret = f(*args, **kwargs)
        Rook().flush()
        return ret

    return handler

try:
    from chalice import Chalice

    class RookoutChalice(Chalice):
        @serverless_rook
        def __call__(self, *args, **kwargs):
            return super(RookoutChalice, self).__call__(*args, **kwargs)


except ImportError:
    pass


"""This module initializes the Rook using default settings when imported."""

import six

try:
    from rook.interface import Rook
    from rook.exceptions import RookCommunicationException

    obj = Rook()
    obj.start()
except RookCommunicationException:
    six.print_("Rook failed to connect to the agent - will continue attempting in the background.")
    import traceback
    traceback.print_exc()
except BaseException:
    six.print_("Rook failed automatic initialization")
    import traceback
    traceback.print_exc()
except ImportError as e:
    six.print_("Rook failed to import dependencies: " + str(e))
